==> amir-0.0.2.tar.gz: amir-0.0.2/README.md <==
[![build status](https://travis-ci.com/amirhessam88/amirhessam.svg?branch=master)](https://travis-ci.com/github/amirhessam88/amirhessam)
[![License](https://img.shields.io/github/license/amirhessam88/amirhessam)](https://github.com/amirhessam88/amirhessam/blob/master/LICENSE)
[![Forks](https://img.shields.io/github/forks/amirhessam88/amirhessam)](https://github.com/amirhessam88/amirhessam/network/members)
[![Stars](https://img.shields.io/github/stars/amirhessam88/amirhessam)](https://github.com/amirhessam88/amirhessam/stargazers)

<p align="center">
<a href="https://www.amirhessam.com/">
  <img src="https://raw.githubusercontent.com/amirhessam88/amirhessam/master/assets/design/logo.png" width="250"></img></a>
</p>

<h1 align="center">
    Utility Functions in Python
</h1>


## Installation

First, install Python 3.6 from https://www.python.org, and then run:

```
pip install amir
```

## Citation
If you use the library in academic work, please consider citing
https://doi.org/10.1117/12.2304418 .

### Bibtex Entry:
```bib
@inproceedings{tahmassebi2018ideeple,
  title={ideeple: Deep learning in a flash},
  author={Tahmassebi, Amirhessam},
  booktitle={Disruptive Technologies in Information Sciences},
  volume={10652},
  pages={106520S},
  year={2018},
  organization={International Society for Optics and Photonics}
}
```
### APA Entry:

Tahmassebi, A. (2018, May). ideeple: Deep learning in a flash. In Disruptive
Technologies in Information Sciences (Vol. 10652, p. 106520S). International
Society for Optics and Photonics.

==> amir-0.0.4.tar.gz: amir-0.0.4/README.md <==
[![build status](https://travis-ci.com/amirhessam88/amirhessam.svg?branch=master)](https://travis-ci.com/github/amirhessam88/amirhessam)
[![License](https://img.shields.io/github/license/amirhessam88/amirhessam)](https://github.com/amirhessam88/amirhessam/blob/master/LICENSE)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/amir)](https://pypi.org/project/amir/)
![PyPI Version](https://img.shields.io/pypi/v/amir)
[![Issues](https://img.shields.io/github/issues/amirhessam88/amirhessam)](https://github.com/amirhessam88/amirhessam/issues)
[![Forks](https://img.shields.io/github/forks/amirhessam88/amirhessam)](https://github.com/amirhessam88/amirhessam/network/members)
[![Stars](https://img.shields.io/github/stars/amirhessam88/amirhessam)](https://github.com/amirhessam88/amirhessam/stargazers)

<p align="center">
<a href="https://www.amirhessam.com/">
  <img src="https://raw.githubusercontent.com/amirhessam88/amirhessam/master/assets/design/logo.png" width="250"></img></a>
</p>

<h1 align="center">
    Utility Functions in Python
</h1>


## Installation

First, install Python 3.6 from https://www.python.org, and then run:

```
pip install amir
```

## Citation
If you use the library in academic work, please consider citing
https://doi.org/10.1117/12.2304418 .

### Bibtex Entry:
```bib
@inproceedings{tahmassebi2018ideeple,
  title={ideeple: Deep learning in a flash},
  author={Tahmassebi, Amirhessam},
  booktitle={Disruptive Technologies in Information Sciences},
  volume={10652},
  pages={106520S},
  year={2018},
  organization={International Society for Optics and Photonics}
}
```
### APA Entry:

Tahmassebi, A. (2018, May). ideeple: Deep learning in a flash. In Disruptive
Technologies in Information Sciences (Vol. 10652, p. 106520S). International
Society for Optics and Photonics.
